@@ -170,7 +170,7 @@ sub Parse::RecDescent::Mail::IMAPClient::Thread::thread
 		
 
 		$_tok = ($_noactions) ? 0 : do {
-		$return = $item{threadmember}||undef;	
+		$return = $item{'threadmember(s)'}||undef;	
 	};
 		unless (defined $_tok)
 		{
@@ -482,7 +482,7 @@ sub Parse::RecDescent::Mail::IMAPClient::Thread::start
 		
 
 		$_tok = ($_noactions) ? 0 : do {
-	$return=$item{thread}||undef;
+	$return=$item{'thread(s?)'}||undef;
 };
 		unless (defined $_tok)
 		{
@@ -803,10 +803,11 @@ package Mail::IMAPClient::Thread; sub new { my $self = bless( {
                                                    'calls' => [
                                                                 'threadmember'
                                                               ],
+                                                   'changed' => 0,
                                                    'opcount' => 0,
                                                    'prods' => [
                                                                 bless( {
-                                                                         'number' => '0',
+                                                                         'number' => 0,
                                                                          'strcount' => 2,
                                                                          'dircount' => 0,
                                                                          'uncommit' => undef,
@@ -844,7 +845,7 @@ package Mail::IMAPClient::Thread; sub new { my $self = bless( {
                                                                                                'lookahead' => 0,
                                                                                                'line' => 11,
                                                                                                'code' => '{
-		$return = $item{threadmember}||undef;	
+		$return = $item{\'threadmember(s)\'}||undef;	
 	}'
                                                                                              }, 'Parse::RecDescent::Action' )
                                                                                     ],
@@ -853,16 +854,16 @@ package Mail::IMAPClient::Thread; sub new { my $self = bless( {
                                                               ],
                                                    'name' => 'thread',
                                                    'vars' => '',
-                                                   'changed' => 0,
                                                    'line' => 10
                                                  }, 'Parse::RecDescent::Rule' ),
                               'NUMBER' => bless( {
                                                    'impcount' => 0,
                                                    'calls' => [],
+                                                   'changed' => 0,
                                                    'opcount' => 0,
                                                    'prods' => [
                                                                 bless( {
-                                                                         'number' => '0',
+                                                                         'number' => 0,
                                                                          'strcount' => 0,
                                                                          'dircount' => 0,
                                                                          'uncommit' => undef,
@@ -871,14 +872,14 @@ package Mail::IMAPClient::Thread; sub new { my $self = bless( {
                                                                          'actcount' => 0,
                                                                          'items' => [
                                                                                       bless( {
-                                                                                               'description' => '/\\\\d+/',
-                                                                                               'rdelim' => '/',
                                                                                                'pattern' => '\\d+',
                                                                                                'hashname' => '__PATTERN1__',
+                                                                                               'description' => '/\\\\d+/',
                                                                                                'lookahead' => 0,
-                                                                                               'ldelim' => '/',
+                                                                                               'rdelim' => '/',
+                                                                                               'line' => 3,
                                                                                                'mod' => '',
-                                                                                               'line' => 3
+                                                                                               'ldelim' => '/'
                                                                                              }, 'Parse::RecDescent::Token' )
                                                                                     ],
                                                                          'line' => undef
@@ -886,7 +887,6 @@ package Mail::IMAPClient::Thread; sub new { my $self = bless( {
                                                               ],
                                                    'name' => 'NUMBER',
                                                    'vars' => '',
-                                                   'changed' => 0,
                                                    'line' => 1
                                                  }, 'Parse::RecDescent::Rule' ),
                               'start' => bless( {
@@ -894,10 +894,11 @@ package Mail::IMAPClient::Thread; sub new { my $self = bless( {
                                                   'calls' => [
                                                                'thread'
                                                              ],
+                                                  'changed' => 0,
                                                   'opcount' => 0,
                                                   'prods' => [
                                                                bless( {
-                                                                        'number' => '0',
+                                                                        'number' => 0,
                                                                         'strcount' => 0,
                                                                         'dircount' => 0,
                                                                         'uncommit' => undef,
@@ -906,14 +907,14 @@ package Mail::IMAPClient::Thread; sub new { my $self = bless( {
                                                                         'actcount' => 1,
                                                                         'items' => [
                                                                                      bless( {
-                                                                                              'description' => '/^\\\\* THREAD /i',
-                                                                                              'rdelim' => '/',
                                                                                               'pattern' => '^\\* THREAD ',
                                                                                               'hashname' => '__PATTERN1__',
+                                                                                              'description' => '/^\\\\* THREAD /i',
                                                                                               'lookahead' => 0,
-                                                                                              'ldelim' => '/',
+                                                                                              'rdelim' => '/',
+                                                                                              'line' => 16,
                                                                                               'mod' => 'i',
-                                                                                              'line' => 16
+                                                                                              'ldelim' => '/'
                                                                                             }, 'Parse::RecDescent::Token' ),
                                                                                      bless( {
                                                                                               'subrule' => 'thread',
@@ -931,7 +932,7 @@ package Mail::IMAPClient::Thread; sub new { my $self = bless( {
                                                                                               'lookahead' => 0,
                                                                                               'line' => 16,
                                                                                               'code' => '{
-	$return=$item{thread}||undef;
+	$return=$item{\'thread(s?)\'}||undef;
 }'
                                                                                             }, 'Parse::RecDescent::Action' )
                                                                                    ],
@@ -940,7 +941,6 @@ package Mail::IMAPClient::Thread; sub new { my $self = bless( {
                                                              ],
                                                   'name' => 'start',
                                                   'vars' => '',
-                                                  'changed' => 0,
                                                   'line' => 15
                                                 }, 'Parse::RecDescent::Rule' ),
                               'threadmember' => bless( {
@@ -949,10 +949,11 @@ package Mail::IMAPClient::Thread; sub new { my $self = bless( {
                                                                       'NUMBER',
                                                                       'thread'
                                                                     ],
+                                                         'changed' => 0,
                                                          'opcount' => 0,
                                                          'prods' => [
                                                                       bless( {
-                                                                               'number' => '0',
+                                                                               'number' => 0,
                                                                                'strcount' => 0,
                                                                                'dircount' => 0,
                                                                                'uncommit' => undef,
@@ -978,7 +979,7 @@ package Mail::IMAPClient::Thread; sub new { my $self = bless( {
                                                                                'line' => undef
                                                                              }, 'Parse::RecDescent::Production' ),
                                                                       bless( {
-                                                                               'number' => '1',
+                                                                               'number' => 1,
                                                                                'strcount' => 0,
                                                                                'dircount' => 0,
                                                                                'uncommit' => undef,
@@ -1006,7 +1007,6 @@ package Mail::IMAPClient::Thread; sub new { my $self = bless( {
                                                                     ],
                                                          'name' => 'threadmember',
                                                          'vars' => '',
-                                                         'changed' => 0,
                                                          'line' => 5
                                                        }, 'Parse::RecDescent::Rule' )
                             }
